zpages

package module
v0.68.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2026 License: Apache-2.0, BSD-3-Clause Imports: 17 Imported by: 17

Documentation

Overview

Package zpages implements a collection of HTML pages that display telemetry stats.

Index

Constants

const Version = "0.68.0"

Version is the current release version of the zpages span processor.

Variables

This section is empty.

Functions

func NewTracezHandler

func NewTracezHandler(sp *SpanProcessor) http.Handler

NewTracezHandler returns an http.Handler that can be used to serve HTTP requests for trace zpages.

Types

type SpanProcessor

type SpanProcessor struct {
	// contains filtered or unexported fields
}

SpanProcessor is an sdktrace.SpanProcessor implementation that exposes zpages functionality for opentelemetry-go.

It tracks all active spans, and stores samples of spans based on latency for non errored spans, and samples for errored spans.

func NewSpanProcessor

func NewSpanProcessor() *SpanProcessor

NewSpanProcessor returns a new SpanProcessor.

func (*SpanProcessor) ForceFlush

func (*SpanProcessor) ForceFlush(context.Context) error

ForceFlush does nothing.

func (*SpanProcessor) OnEnd

func (ssm *SpanProcessor) OnEnd(span sdktrace.ReadOnlySpan)

OnEnd processes all spans and reports them with zpages.

func (*SpanProcessor) OnStart

func (ssm *SpanProcessor) OnStart(_ context.Context, span sdktrace.ReadWriteSpan)

OnStart adds span as active and reports it with zpages.

func (*SpanProcessor) Shutdown

func (*SpanProcessor) Shutdown(context.Context) error

Shutdown does nothing.

Directories

Path Synopsis
Package internal provides non-public types for the zpages package.
Package internal provides non-public types for the zpages package.

Jump to